SystemOrganization addCategory: #ReleaseBuilder!

Object subclass: #ReleaseBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilder commentStamp: '<historical>' prior: 0!
I'm responsible to help people releasing various distribution of Squeak!

!ReleaseBuilder methodsFor: 'utilities' stamp: 'ar 9/27/2005 20:10'!
cleanUpChanges
	"Clean up the change sets"

	"ReleaseBuilder new cleanUpChanges"
	
	| projectChangeSetNames |

	"Delete all changesets except those currently used by existing projects."
	projectChangeSetNames := Project allSubInstances collect: [:proj | proj changeSet name].
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs | (projectChangeSetNames includes: cs) not].
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 15:28'!
cleanUpEtoys
	"ReleaseBuilder new cleanUpEtoys"


	StandardScriptingSystem removeUnreferencedPlayers.

	(self confirm: 'Remove all projects and players?')
		ifFalse: [^self].
	Project removeAllButCurrent.

	#('Morphic-UserObjects' 'EToy-UserObjects' 'Morphic-Imported' )
		do: [:each | SystemOrganization removeSystemCategory: each]! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 15:33'!
finalCleanup
	"ReleaseBuilder new finalCleanup"


	Smalltalk forgetDoIts.

	DataStream initialize.
	Behavior flushObsoleteSubclasses.

	"The pointer to currentMethod is not realy needed (anybody care to fix this) and often holds on to obsolete bindings"
	MethodChangeRecord allInstancesDo: [:each | each noteNewMethod: nil].

	self cleanUpEtoys.
	SmalltalkImage current fixObsoleteReferences.

	Smalltalk flushClassNameCache.
	3 timesRepeat: [
		Smalltalk garbageCollect.
		Symbol compactSymbolTable.
	].
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:41'!
finalStripping
	"ReleaseBuilder new finalStripping"
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:23'!
fixObsoleteReferences
	"ReleaseBuilder new fixObsoleteReferences"

	| informee obsoleteBindings obsName realName realClass |
	Preference allInstances do: [:each | 
		informee := each instVarNamed: #changeInformee.
		((informee isKindOf: Behavior)
			and: [informee isObsolete])
			ifTrue: [
				Transcript show: each name; cr.
				each instVarNamed: #changeInformee put: (Smalltalk at: (informee name copyReplaceAll: 'AnObsolete' with: '') asSymbol)]].
 
	CompiledMethod allInstances do: [:method |
		obsoleteBindings := method literals select: [:literal |
			literal isVariableBinding
				and: [literal value isBehavior]
				and: [literal value isObsolete]].
		obsoleteBindings do: [:binding |
			obsName := binding value name.
			Transcript show: obsName; cr.
			realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
			realClass := Smalltalk at: realName asSymbol ifAbsent: [UndefinedObject].
			binding isSpecialWriteBinding
				ifTrue: [binding privateSetKey: binding key value: realClass]
				ifFalse: [binding key: binding key value: realClass]]].


	Behavior flushObsoleteSubclasses.
	Smalltalk garbageCollect; garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [SystemNavigation default inspect]! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'ar 9/27/2005 21:44'!
initialCleanup
	"Perform various image cleanups in preparation for making a Squeak gamma release candidate image."
	"ReleaseBuilder new initialCleanup"
	
	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.

	(Object classPool at: #DependentsFields) size > 1 ifTrue: [self error:'Still have dependents'].
	Undeclared isEmpty ifFalse: [self error:'Please clean out Undeclared'].

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ScriptingSystem deletePrivateGraphics.  "?"
	
	self cleanUpChanges.
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.

	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.

	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Smalltalk garbageCollect.
	
	SMSqueakMap default purge.
	
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 16:25'!
installPreferences
	Preferences initialize.
	Preferences chooseInitialSettings.
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 11:02'!
installReleaseSpecifics
	"ReleaseBuilder new installReleaseSpecifics"
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:53'!
installVersionInfo
	"ReleaseBuilder new installVersionInfo"
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'sd 9/26/2004 13:35'!
makeSqueaklandRelease
	"ReleaseBuilder new makeSqueaklandRelease"

	self 
		makeSqueaklandReleasePhasePrepare; 		makeSqueaklandReleasePhaseStripping; 		makeSqueaklandReleasePhaseFinalSettings; 		makeSqueaklandReleasePhaseCleanup! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'ar 9/27/2005 21:45'!
makeSqueaklandReleasePhaseCleanup
	"ReleaseBuilder new makeSqueaklandReleasePhaseCleanup"

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ChangeSet 
		removeChangeSetsNamedSuchThat: [:cs | cs name ~= ChangeSet current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.
	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	"Remove existing player references"
	References keys do: [:k | References removeKey: k].
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors isEmpty 
		ifFalse: [self error: 'Still have obsolete behaviors'].

	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	Smalltalk fixObsoleteReferences.
	Smalltalk abandonTempNames.
	Smalltalk zapAllOtherProjects.
	Smalltalk forgetDoIts.
	Smalltalk flushClassNameCache.
	3 timesRepeat: 
			[Smalltalk garbageCollect.
			Symbol compactSymbolTable]! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'md 2/24/2006 15:18'!
makeSqueaklandReleasePhaseFinalSettings
	"ReleaseBuilder new makeSqueaklandReleasePhaseFinalSettings"

	| serverName serverURL serverDir updateServer highestUpdate newVersion |

	ProjectLauncher splashMorph: (FileDirectory default readOnlyFileNamed: 'scripts\SqueaklandSplash.morph') fileInObjectAndCode.

	"Dump all morphs so we don't hold onto anything"
	World submorphsDo:[:m| m delete].

	#(
		(honorDesktopCmdKeys false)
		(warnIfNoChangesFile false)
		(warnIfNoSourcesFile false)
		(showDirectionForSketches true)
		(menuColorFromWorld false)
		(unlimitedPaintArea true)
		(useGlobalFlaps false)
		(mvcProjectsAllowed false)
		(projectViewsInWindows false)
		(automaticKeyGeneration true)
		(securityChecksEnabled true)
		(showSecurityStatus false)
		(startInUntrustedDirectory true)
		(warnAboutInsecureContent false)
		(promptForUpdateServer false)
		(fastDragWindowForMorphic false)

		(externalServerDefsOnly true)
		(expandedFormat false)
		(eToyFriendly true)
		(eToyLoginEnabled true)
		(magicHalos true)
		(mouseOverHalos true)
		(biggerHandles false)
		(selectiveHalos true)
		(includeSoundControlInNavigator true)
		(readDocumentAtStartup true)
		(preserveTrash true)
		(slideDismissalsToTrash true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last].
	"Workaround for bug"
	Preferences enable: #readDocumentAtStartup.

	World color: (Color r: 0.9 g: 0.9 b: 1.0).

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].
	SystemVersion current resetHighestUpdate.

	"Add the squeakalpha update stream"
	serverName := 'Squeakalpha'.
	serverURL := 'squeakalpha.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'updates/';
		altUrl: serverDir;
		user: 'sqland';
		password: nil.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	"Add the squeakland update stream"
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public_html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' initialAnswer: 'Squeakland 3.8.' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	(self confirm: self version , '
Is this the correct version designation?
If not, choose no, and fix it.') ifFalse: [^ self].
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'ar 9/27/2005 21:45'!
makeSqueaklandReleasePhasePrepare
	"ReleaseBuilder new makeSqueaklandReleasePhasePrepare"

	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.
	Preferences initialize.
	"(Object classPool at: #DependentsFields) size > 1 ifTrue: [self error:'Still have dependents']."
	Undeclared isEmpty ifFalse: [self error:'Please clean out Undeclared'].

	"Dump all projects"
	Project allSubInstancesDo:[:prj| prj == Project current ifFalse:[Project deletingProject: prj]].

	"Set new look so we don't need older fonts later"
	StandardScriptingSystem applyNewEToyLook.

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ScriptingSystem deletePrivateGraphics.
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs| cs name ~= ChangeSet current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.
	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	"Remove existing player references"
	References keys do:[:k| References removeKey: k].

	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Smalltalk garbageCollect.
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'sd 9/26/2004 13:35'!
makeSqueaklandReleasePhaseStripping
	"ReleaseBuilder new makeSqueaklandReleasePhaseStripping"

	#(#Helvetica #Palatino #Courier #ComicSansMS )
		do: [:n | TextConstants
				removeKey: n
				ifAbsent: []].
	Smalltalk
		at: #Player
		ifPresent: [:superCls | superCls
				allSubclassesDo: [:cls | 
					cls isSystemDefined
						ifFalse: [cls removeFromSystem].
					cls := nil]].
	Smalltalk garbageCollect.
	Smalltalk discardFFI; discardSUnit; discardSpeech; yourself.
	"discardMVC;"
	SystemOrganization removeEmptyCategories.
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	Smalltalk garbageCollect; garbageCollect.
	DataStream initialize.
	Smalltalk fixObsoleteReferences! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:58'!
prepareReleaseImage
	"Perform various image cleanups in preparation for making a Squeak gamma release candidate image."
	"ReleaseBuilder new prepareReleaseImage"
	
	(self confirm: 'Are you sure you want to prepare a release image?
This will perform several irreversible cleanups on this image.')
		ifFalse: [^ self].

	self
		initialCleanup;
		installPreferences;
		finalStripping;
		installReleaseSpecifics;
		finalCleanup;
		installVersionInfo
! !

ReleaseBuilder subclass: #ReleaseBuilderDeveloper
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderDeveloper commentStamp: 'gk 2/28/2005 13:27' prior: 0!
This release builder subclass is used for the official Squeak distribution Basic, which currently is the base image of Squeak.
Full is then built on top of Basic using a loadscript from SqueakMap. Minimal is constructed using another script from SqueakMap that removes packages that are included in Basic.!

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'mir 11/26/2004 16:18'!
cleanUpChanges
	"Clean up the change sets"

	"ReleaseBuilderDeveloper new cleanUpChanges"
	
! !

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'mir 4/7/2005 11:56'!
installPreferences
	super installPreferences.
	#(
		(updateFromServerAtStartup true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last]! !

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:23'!
installReleaseSpecifics
	"Currently just clear and add the ServerDirectories
	and update streams we want as default."

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].

	"Add default entries, added an entry for the new file area.
	The others are the current ones that see to work 
	as of 2005-02-28 and I recreated them using source."
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		user: '';
		server: 'box1.squeakfoundation.org';
		altUrl: 'http://box1.squeakfoundation.org/files';
		directory: 'files';
		keepAlive: false) named: 'Squeak.org Archive'.
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		server: 'st.cs.uiuc.edu';
		user: 'anonymous';
		directory: '/Smalltalk/Squeak';
		keepAlive: false) named: 'UIUC Archive'.	
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		server: 'ftp.create.ucsb.edu';
		user: 'anonymous';
		directory: '/pub/Smalltalk/Squeak';
		keepAlive: false) named: 'UCSBCreate Archive'.
	ServerDirectory addServer: SuperSwikiServer defaultSuperSwiki named: 'Bob SuperSwiki'.
	ServerDirectory addServer: (SuperSwikiServer new 
		type: #http;
		server: 'squeakland.org:8080';
		altUrl: 'http://www.squeakland.org/uploads';
		directory: '/super/SuperSwikiProj';
		keepAlive: false;
		acceptsUploads: true) named: 'Squeakland SuperSwiki'.
	ServerDirectory addServer: (HTTPServerDirectory new 
		type: #ftp;
		user: 'sqland';
		server: 'www.squeakland.org';
		altUrl: 'http://www.squeakland.org/projects';
		directory: 'projects';
		keepAlive: false) named: 'Squeakland Projects'.

"Add the update streams here just as Squeakland does?
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.
	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public:=html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.
"
! !

ReleaseBuilder subclass: #ReleaseBuilderNihongo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderNihongo methodsFor: 'release' stamp: 'md 2/24/2006 15:59'!
release
	"self release"
	
	Utilities emptyScrapsBook.

	Display setExtent: 960@720 depth: 16.
	World color: (Color r: 0.935 g: 0.935 b: 0.935).

	"Preferences takanawa."
	Preferences setPreference: #magicHalos toValue: false.
	Preferences setPreference: #magicHalos toValue: true.
	Preferences setPreference: #mouseOverHalos toValue: false.
	Preferences setPreference: #mouseOverHalos toValue: true.

	Player abandonUnnecessaryUniclasses.
	Player freeUnreferencedSubclasses.
	Player removeUninstantiatedSubclassesSilently.

	PartsBin initialize.
	Flaps disableGlobalFlaps: false.
	Flaps addAndEnableEToyFlaps.
	ActiveWorld addGlobalFlaps.
	Flaps sharedFlapsAlongBottom.

	Locale currentPlatform: (Locale isoLanguage: 'ja').
	Locale switchToID: (LocaleID isoLanguage: 'ja').
	Preferences restoreDefaultFonts.
	StrikeFont setupDefaultFallbackFont.
	Project current updateLocaleDependents.

	"Dump all projects"
	Project allSubInstancesDo:[:prj| prj == Project current ifFalse:[Project deletingProject: prj]].

	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.


! !

ReleaseBuilder subclass: #ReleaseBuilderSqueakland
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:14'!
finalCleanup
	"ReleaseBuilder new initialCleanup"


	Smalltalk abandonTempNames.
	Smalltalk zapAllOtherProjects.
	
	super finalCleanup! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:40'!
finalStripping
	"ReleaseBuilderSqueakland new finalStripping"

	#(#Helvetica #Palatino #Courier #ComicSansMS )
		do: [:n | TextConstants
				removeKey: n
				ifAbsent: []].
	Smalltalk
		at: #Player
		ifPresent: [:superCls | superCls
				allSubclassesDo: [:cls | 
					cls isSystemDefined
						ifFalse: [cls removeFromSystem].
					cls := nil]].
	Smalltalk garbageCollect.
	Smalltalk discardFFI; discardSUnit; discardSpeech; yourself.
	"discardMVC;"
	SystemOrganization removeEmptyCategories.
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'ar 9/27/2005 21:45'!
initialCleanup
	"ReleaseBuilder new initialCleanup"

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs| cs name ~= ChangeSet current name].

	super initialCleanup! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'md 2/24/2006 15:18'!
installPreferences

	#(
		(honorDesktopCmdKeys false)
		(warnIfNoChangesFile false)
		(warnIfNoSourcesFile false)
		(showDirectionForSketches true)
		(menuColorFromWorld false)
		(unlimitedPaintArea true)
		(useGlobalFlaps false)
		(mvcProjectsAllowed false)
		(projectViewsInWindows false)
		(automaticKeyGeneration true)
		(securityChecksEnabled true)
		(showSecurityStatus false)
		(startInUntrustedDirectory true)
		(warnAboutInsecureContent false)
		(promptForUpdateServer false)
		(fastDragWindowForMorphic false)

		(externalServerDefsOnly true)
		(expandedFormat false)
		(eToyFriendly true)
		(eToyLoginEnabled true)
		(magicHalos true)
		(mouseOverHalos true)
		(biggerHandles false)
		(selectiveHalos true)
		(includeSoundControlInNavigator true)
		(readDocumentAtStartup true)
		(preserveTrash true)
		(slideDismissalsToTrash true)
		(propertySheetFromHalo true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last].
	"Workaround for bug"
	Preferences enable: #readDocumentAtStartup.
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:24'!
installReleaseSpecifics
	"ReleaseBuilderSqueakland new installReleaseSpecifics"

	| serverName serverURL serverDir updateServer |

	ProjectLauncher splashMorph: (FileDirectory default readOnlyFileNamed: 'scripts\SqueaklandSplash.morph') fileInObjectAndCode.

	"Dump all morphs so we don't hold onto anything"
	World submorphsDo:[:m| m delete].

	World color: (Color r: 0.9 g: 0.9 b: 1.0).

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].
	SystemVersion current resetHighestUpdate.

	"Add the squeakalpha update stream"
	serverName := 'Squeakalpha'.
	serverURL := 'squeakalpha.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'updates/';
		altUrl: serverDir;
		user: 'sqland';
		password: nil.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	"Add the squeakland update stream"
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public_html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:23'!
installVersionInfo
	"ReleaseBuilderSqueakland new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := FillInTheBlank request: 'New version designation:' initialAnswer: 'Squeakland 3.8.' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	(self confirm: self version , '
Is this the correct version designation?
If not, choose no, and fix it.') ifFalse: [^ self].
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'tak 11/28/2005 17:25'!
setupLanguageSpecifics
	"ReleaseBuilderSqueakland new setupLanguageSpecifics"
	Locale current languageEnvironment setupSqueaklandSpecifics! !
